<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:g="http://graphml.graphdrawing.org/xmlns"
                xmlns="http://www.w3.org/1999/xhtml">
    <xsl:output method="html"/>

    <xsl:template match="/">
        <html>
            <head>
                <link href="http://netdna.bootstrapcdn.com/bootstrap/3.1.1/css/bootstrap.min.css" rel="stylesheet" type="text/css" id="bootstrap.css"/>
            </head>
            <body>
                <xml id="graphml" style="display: none">
                    <g:graphml>
                        <xsl:apply-templates select="impacts" mode="IMPACT"/>
                        <!--<xsl:apply-templates select="impacts" mode="RELATIONAL"/>-->
                    </g:graphml>
                </xml>
                <div class="container">
                    <div id="Graph"/>
                    <script src="/resource/js/viz.js">//</script>
                    <script src="/resource/js/viz-graphml.js">//</script>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="impacts" mode="IMPACT">
        <g:graph id="G" edgedefault="directed">
            <g:key for="graph" id="rankdir">
                <g:default>BT</g:default>
            </g:key>
            <g:key for="node" id="shape">
                <g:default>plaintext</g:default>
            </g:key>
            <xsl:apply-templates select="source" mode="IMPACT"/>
            <xsl:apply-templates select="source/target" mode="IMPACT"/>
        </g:graph>
    </xsl:template>
    <xsl:template match="source" mode="IMPACT">
        <g:node id="{@class}">
            <g:data key="shape">ellipse</g:data>
        </g:node>
    </xsl:template>
    <xsl:template match="target" mode="IMPACT">
        <xsl:variable name="source-prefix" select="concat(@source-prefix, substring-after('true_',string(boolean(@source-prefix))))"/>
        <xsl:variable name="target-prefix" select="concat(@target-prefix, substring-after('true_',string(boolean(@target-prefix))))"/>
        <g:edge source="{$source-prefix}{parent::*/@class}" target="{$target-prefix}{@class}">
            <g:data key="label">
                <xsl:if test="@custom='true'">© </xsl:if>
                <xsl:choose>
                    <xsl:when test="@mode='redundant'">r </xsl:when>
                    <xsl:when test="@mode='proportional'">% </xsl:when>
                    <xsl:when test="@mode='redundantOrProportional'">r|% </xsl:when>
                </xsl:choose>
                <xsl:value-of select="@description"/>
            </g:data>
            <xsl:if test="@description='EXTERNAL'">
                <g:data key="labelURL">http://cctools.in2p3.fr/mago/services.html</g:data>
            </xsl:if>
        </g:edge>
    </xsl:template>

    <!-- graph -->
    <xsl:template match="impacts" mode="RELATIONAL">
        <g:graph id="G" edgedefault="directed">
            <g:key for="graph" id="rankdir">
                <g:default>LR</g:default>
            </g:key>
            <xsl:apply-templates select="source" mode="RELATIONAL"/>
            <xsl:apply-templates select="source/target" mode="RELATIONAL"/>
        </g:graph>
    </xsl:template>
    <!-- nodes -->
    <xsl:template match="source[not(prefix)]" mode="RELATIONAL">
        <g:node id="_{@class}">
            <g:data key="label"><xsl:value-of select="@class"/></g:data>
            <g:data key="shape">box</g:data>
        </g:node>
    </xsl:template>
    <xsl:template match="source[prefix]" mode="RELATIONAL">
        <xsl:apply-templates select="prefix" mode="RELATIONAL"/>
    </xsl:template>
    <xsl:template match="prefix" mode="RELATIONAL">
        <xsl:variable name="class" select="concat(text(),'_',parent::source/@class)"/>
        <g:node id="_{$class}">
            <g:data key="label"><xsl:value-of select="$class"/></g:data>
            <g:data key="shape">box</g:data>
        </g:node>
    </xsl:template>
    <!-- edges -->
    <xsl:template match="source[prefix]/target" mode="RELATIONAL" priority="3">
        <xsl:variable name="current" select="."/>
        <xsl:for-each select="parent::source/prefix">
            <xsl:variable name="source" select="concat(text(),'_',parent::source/@class)"/>
            <xsl:variable name="target">
                <xsl:if test="$current[@class=/impacts/source[prefix]/@class]"><xsl:value-of select="text()"/>_</xsl:if>
                <xsl:value-of select="$current/@class"/>
            </xsl:variable>
            <xsl:apply-templates select="$current" mode="R">
                <xsl:with-param name="source" select="$source"/>
                <xsl:with-param name="target" select="$target"/>
            </xsl:apply-templates>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="source[not(prefix)]/target[@class=/impacts/source[prefix]/@class]" mode="RELATIONAL" priority="2">
        <xsl:variable name="current" select="."/>
        <xsl:for-each select="/impacts/source[@class = $current/@class]/prefix">
            <xsl:variable name="source" select="$current/parent::source/@class"/>
            <xsl:variable name="target" select="concat(text(),'_',$current/@class)"/>
            <xsl:apply-templates select="$current" mode="R">
                <xsl:with-param name="source" select="$source"/>
                <xsl:with-param name="target" select="$target"/>
            </xsl:apply-templates>
        </xsl:for-each>
    </xsl:template>
    <xsl:template match="source[not(prefix)]/target[not(@class=/impacts/source[prefix]/@class)]" mode="RELATIONAL" priority="1">
        <xsl:apply-templates select="." mode="R">
            <xsl:with-param name="source" select="parent::source/@class"/>
            <xsl:with-param name="target" select="@class"/>
        </xsl:apply-templates>
    </xsl:template>
    <xsl:template match="target" mode="R">
        <xsl:param name="source"/>
        <xsl:param name="target"/>
        <xsl:variable name="domain"><xsl:value-of select="$source"/>2<xsl:value-of select="$target"/></xsl:variable>
        <g:edge source="_{$source}" target="{$domain}"/>
        <g:node id="{$domain}">
            <g:data key="shape">box</g:data>
        </g:node>
        <g:edge source="{$domain}" target="_{$target}"/>
    </xsl:template>
</xsl:stylesheet>